post_process_obtained_certificate

Function post_process_obtained_certificate 

async fn post_process_obtained_certificate(
    config: &AcmeConfig,
    certificate_pem: &str,
    private_key_pem: &str,
) -> Result<(), Box<dyn Error + Send + Sync>>
Saves the obtained certificate and private key to files if the save paths are configured, and executes the post-obtain command if configured.