pub struct AcmeConfig {Show 17 fields
pub rustls_client_config: ClientConfig,
pub domains: Vec<String>,
pub challenge_type: ChallengeType,
pub contact: Vec<String>,
pub directory: String,
pub eab_key: Option<Arc<ExternalAccountKey>>,
pub profile: Option<String>,
pub account_cache: AcmeCache,
pub certificate_cache: AcmeCache,
pub certified_key_lock: Arc<RwLock<Option<Arc<CertifiedKey>>>>,
pub tls_alpn_01_data_lock: Arc<RwLock<Option<(Arc<CertifiedKey>, String)>>>,
pub http_01_data_lock: Arc<RwLock<Option<(String, String)>>>,
pub dns_provider: Option<Arc<dyn DnsProvider + Send + Sync>>,
pub renewal_info: Option<(RenewalInfo, Instant)>,
pub account: Option<Account>,
pub save_paths: Option<(PathBuf, PathBuf)>,
pub post_obtain_command: Option<String>,
}Expand description
Represents the configuration for the ACME client.
Fields
rustls_client_config: ClientConfigThe Rustls client configuration to use for ACME communication.
domains: Vec<String>The domains for which to request certificates.
challenge_type: ChallengeTypeThe type of challenge to use for ACME certificate issuance.
contact: Vec<String>The contact information for the ACME account.
directory: StringThe directory URL for the ACME server.
eab_key: Option<Arc<ExternalAccountKey>>The optional EAB key
profile: Option<String>The optional ACME profile name
account_cache: AcmeCacheThe cache for storing ACME account information.
certificate_cache: AcmeCacheThe cache for storing ACME certificate information.
certified_key_lock: Arc<RwLock<Option<Arc<CertifiedKey>>>>The lock for managing the certified key.
tls_alpn_01_data_lock: Arc<RwLock<Option<(Arc<CertifiedKey>, String)>>>The lock for managing the TLS-ALPN-01 data.
http_01_data_lock: Arc<RwLock<Option<(String, String)>>>The lock for managing the HTTP-01 data.
dns_provider: Option<Arc<dyn DnsProvider + Send + Sync>>The ACME DNS provider.
renewal_info: Option<(RenewalInfo, Instant)>The certificate renewal information.
account: Option<Account>The ACME account information
save_paths: Option<(PathBuf, PathBuf)>The paths to TLS certificate and private key files to save the obtained certificate and private key.
post_obtain_command: Option<String>The command to execute after certificates and private key are obtained,
with environment variables FERRON_ACME_DOMAIN, FERRON_ACME_CERT_PATH and FERRON_ACME_KEY_PATH set.